
//   Copyright 2020 Esri
//   Licensed under the Apache License, Version 2.0 (the "License");
//   you may not use this file except in compliance with the License.
//   You may obtain a copy of the License at
//
//   http://www.apache.org/licenses/LICENSE-2.0
//
//   Unless required by applicable law or agreed to in writing, software
//   distributed under the License is distributed on an "AS IS" BASIS,
//   WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
//   See the License for the specific language governing permissions and
//   limitations under the License.


package com.example.app;

import java.io.File;

import com.esri.arcgisruntime.loadable.LoadStatus;
import com.esri.arcgisruntime.mapping.MobileMapPackage;
import com.esri.arcgisruntime.ArcGISRuntimeEnvironment;
import com.esri.arcgisruntime.mapping.view.MapView;

import javafx.scene.control.Alert;
import javafx.application.Application;
import javafx.scene.Scene;
import javafx.scene.layout.StackPane;
import javafx.stage.Stage;


public class App extends Application {

    private MapView mapView;

    private MobileMapPackage mobileMapPackage;


    @Override
    public void start(Stage stage) {

        try {

            // create the stack pane and JavaFX application scene
            StackPane stackPane = new StackPane();
            Scene scene = new Scene(stackPane);

            // set title, size, and add scene to stage

            stage.setTitle("Display a map from a mobile map package");

            stage.setWidth(800);
            stage.setHeight(700);
            stage.setScene(scene);
            stage.show();

            // Note: it is not best practice to store API keys in source code.
            // The API key is referenced here for the convenience of this tutorial.
            String yourApiKey = "YOUR_API_KEY";
            ArcGISRuntimeEnvironment.setApiKey(yourApiKey);

            // create a map view
            mapView = new MapView();

            //Set the location of the .mmpk file to the project root folder
            final String mmpkPath = new File(System.getProperty("user.dir"), "./MahouRivieraTrails.mmpk").getAbsolutePath();
            mobileMapPackage = new MobileMapPackage(mmpkPath);

            mobileMapPackage.loadAsync();
            mobileMapPackage.addDoneLoadingListener(() -> {
                if (mobileMapPackage.getLoadStatus() == LoadStatus.LOADED && mobileMapPackage.getMaps().size() > 0) {
                    //add the map from the mobile map package to the map view
                    mapView.setMap(mobileMapPackage.getMaps().get(0));
                } else {
                    Alert alert = new Alert(Alert.AlertType.ERROR, "Failed to load the mobile map package");
                    alert.show();
                }
            });

            // add the map view to stack pane
            stackPane.getChildren().add(mapView);

        } catch (Exception e) {
            // on any error, display the stack trace
            e.printStackTrace();
        }

    }

    // Stops and releases all resources used in application.
    @Override
    public void stop() {
        if (mapView != null) {
            mapView.dispose();
        }
    }
    public static void main (String[] args){
        Application.launch(args);
    }
}



